local myname, ns = ...

local merge = function(t1, t2)
    if not t2 then return t1 end
    for k, v in pairs(t2) do
        t1[k] = v
    end
end
ns.merge = merge

local path_meta = {__index = {
    label = "Path to treasure",
    atlas = "map-icon-SuramarDoor.tga", -- 'PortalPurple'
    path = true,
    scale = 1.1,
}}
local path = function(details)
    return setmetatable(details or {}, path_meta)
end
ns.path = path

ns.map_spellids = {
    -- [862] = 0, -- Zuldazar
    -- [863] = 0, -- Nazmir
    -- [864] = 0, -- Vol'dun
    -- [895] = 0, -- Tiragarde Sound
    -- [896] = 0, -- Drustvar
    -- [942] = 0, -- Stormsong Valley
}

ns.points = {
    --[[ my structure:
    [uiMapID] = { 
        [coord] = {
                                  -- text
            label    = [string],  -- label: text that'll be the label
            note     = [string],  -- some text which might be helpful

                                  -- type of establishment (determines map icon)
            bar      = [boolean], -- if a bar (serves alcohol)
            food     = [boolean], -- if a restaurant (serves food), indicate type in note
            shop     = [boolean], -- if sells items, either IC or in game, indicate type in note, not food/alcohol
            poi      = [boolean], -- is a point of interest
            ship     = [boolean], -- if a ship
            official = [boolean], -- if an official building
            basement = [boolean], -- if a basement or cellar
            misc     = [boolean], -- if a miscellaneous location

                                  -- modifiers
            empty    = [boolean], -- if empty
            hostile  = [boolean], -- if occupied by hostile NPCs
            closed   = [boolean], -- if the door is closed / building not enterable
            novendor = [boolean], -- if there's no player-friendly vendor

                                  -- counts (icons)
            beds     = [int],     -- number of beds in the building, optional
            tables   = [int],     -- number of empty tables, optional
            seats    = [int],     -- number of empty seats, optional
            maxseats = [int],     -- size of the largest table
            animals  = [int],     -- number of pettable animals, indicate type in note
            floors   = [int],     -- number of floors
            decks    = [int],     -- number of decks on a ship
            shipsize = [enum],    -- the size of the ship, LARGE, MEDIUM, SMALL, BOAT, SAILBOAT

                                  -- extra icons
            dancing  = [boolean], -- is there dancing?
            music    = [boolean], -- is there music?
            cuisine  = [string],  -- what kind of cuisine?

            claimed  = [boolean], -- there can be multiple claims
            claims   = { [list] } -- claim structure:
                                     { player = [string],          -- optional
                                       guild  = [string],          -- optional, should have either guild or player
                                       server = [string]-[string], -- server-region
                                       label  = [string],          -- label for this claim
                                       note   = [string],          -- note for this claim
                                       atlas  = [string],          -- atlas icon for this claim
                                       scale  = [string],          -- icon scale for this claim
                                     },
            
        },
    },
    --]]
    [1161] = { -- Boralus
        -- bars
        [75171441] = { label = "Harbor Bar", bar = true, tables = 1, seats = 10, maxseats = 2, floors = 2, beds = 2, },
        [67114080] = { label = "Brews from the Mist", bar = true, food = true, cuisine = "Pandaren drinks", }, 
        [73501384] = { label = "Snug Harbor Inn", bar = true, food = true, tables = 2, seats = 9, maxseats = 4, animals = 1, cuisine = "Kul Tiran foods", note = "Small library on second floor", floors = 2, beds = 3, }, 
        [69412981] = { label = "Rudy the Rat", bar = true, }, 
        [74051786] = { label = "Harborside Spirits", bar = true, seats = 2, note = "Allison Weber", },
        [54987437] = { label = "The Cupola Cafe", bar = true, tables = 1, maxseats = 4, seats = 15, note = "Overpriced hipster coffee; note there are no empty booths", food = true, cuisine = "Seafood", },
        [53486576] = { label = "The Scurvy Lamb", bar = true, novendor = true, tables = 3, seats = 6, maxseats = 2, beds = 1, empty = true, },
        [57836904] = { label = "Pinky's Groggery", bar = true, tables = 5, seats = 13, maxseats = 6, }, 
        [48104508] = { label = "Stephen's Food Court", note  = "Several places to buy food from the Stevens family", food = true, bar = true, tables = 2, seats = 7, maxseats = 4, cuisine = "Food Court", },
        [52855049] = { label = "Barnacled Crab", note = "Tavern (no vendor)", seats = 9, tables = 2, beds = 1, maxseats = 2, bar = true, food = true, floors = 2, cuisine = "Seafood", dancing = true, },
        [55794398] = { label = "The Loose Cannon", note = "Run by Crimper Mirjam, brawling upstairs", bar = true, dancing = true, tables = 1, food = true, cuisine = "Seafood", maxseats = 2, seats = 3, floors = 2, beds = 3, animals = 4, },
        [54224523] = { label = "The Kelp Club", note = "Nightclub (possible strip joint)", hostile = true, floors = 3, seats = 28, tables = 3, maxseats = 2, bar = true, dancing = true, animals = 2, novendor = true, food = true, cuisine = "Seafood buffet (downstairs)", }, 
        [61194033] = { label = "Dampwick Tavern", hostile = true, novendor = true, bar = true, beds = 3, seats = 2, }, 
        [59243779] = { label = "The Drunken Gryphon", hostile = true, novendor = true, bar = true, tables = 1, seats = 13, maxseats = 6, beds = 1, floors = 2, },
        [65394018] = { label = "Anchors Away", note = "Ron Mahogany, the Anchor Man", bar = true, floors = 2, desks = 1, seats = 3, maxseats = 2, tables = 1, animals = 3, },
        [54013443] = { label = "Priscilla's Parlor", note = "Empty bar", empty = true, bar = true, novendor = true, hostile = true, tables = 3, seats = 12, maxseats = 4, floors = 2, },
        [51604416] = { label = "Hook Point Bar", seats = 22, maxseats = 6, tables = 3, bar = true, novendor = true, hostile = true, },
        [55852506] = { label = "Salt and Shandy", official = true, note = "War Headquarters (PVP)", bar = true, floors = 2, tables = 9, seats = 20, maxseats = 4, food = true, cuisine = "Feasts (PVP)", }, 
        [53622077] = { label = "The Ravens Flock Tavern", food = true, cuisine = "Seafood", novendor = true, bar = true, seats = 20, tables = 7, maxseats = 4, beds = 1, floors = 4, note = "Door is up the stairs, two tables at street level", },
        [52841813] = { label = "Hops, Line, & Sinker Brewing (indoors)", food = true, bar = true, music = true, tables = 3, seats = 13, maxseats = 3, floors = 2, },
        [55141710] = { label = "Hops, Line, & Sinker Brewing (outdoors)", food = true, bar = true, tables = 2, seats = 6, maxseats = 4, animals = 1, cuisine = "Pub food", },
        [63111710] = { label = "Scully's Catch of the Day", food = true, note = "Escaped crabs outside", novendor = true, tables = 3, seats = 13, maxseats = 4, empty = true, bar = true, cuisine = "Seafood", }, 
        [74337268] = { label = "Friends and Anenomes", seats = 9, tables = 2, maxseats = 2, bar = true, novendor = true, misc = true, floors = 2, note = "Two occupied beds and a parrot upstairs", }, 
        [73416876] = { label = "The Curious Octopus", food = true, bar = true, music = true, dancing = true, tables = 5, seats = 20, maxseats = 5, floors = 2, note = "Jaela Billman cannot set your hearth, despite appearances", animals = 3, },
        [66346030] = { label = "The Shark", bar = true, tables = 1, novendor = true, seats = 2, maxseats = 2, beds = 3, floors = 2, }, 
        [56436284] = { label = "Fireside Anchors", bar = true, closed = true, note = "The firepit is around back", },
        [58406424] = { label = "Fireside Anchors (firepit)", bar = true, novendor = true, seats = 6, },

        -- food only (no bar)
        [75611652] = { label = "Pandaria Cuisine", food = true, cuisine = "Pandaria cuisine", tables = 3, seats = 6, maxseats = 2, },
        [69794025] = { label = "Paw'don Bean Dumplings", food = true, novendor = true, cuisine = "Pandaren dumplings", tables = 2, seats = 4, maxseats = 2, },
        [66623496] = { label = "Fish Vendor's Stand", food = true, empty = true, note = "Empty", novendor = true, cuisine = "Fish", },
        [72271726] = { label = "Fish Vendor's Stand", food = true, empty = true, note = "Empty", novendor = true, cuisine = "Fish", },
        [66323340] = { label = "Trader from the Mists", food = true, note = "Traveler Nali", cuisine = "Pandaria cuisine", }, 
        [70562388] = { label = "Trader from the North", food = true, cuisine = "Northrend cuisine", note = "Tal'ana the Tuskar", },
        [70022394] = { label = "Jerked Meat & Fish", food = true, cuisine = "Dried meats", note = "Raina Lee", },
        [70502118] = { label = "Fallhaven Sausages", food = true, cuisine = "Sausages", note = "Charisse Payton", },
        [49354873] = { label = "Luke Cutler", note = "Meat vendor", food = true, cuisine = "Butcher", },
        [49374744] = { label = "Cynthia Sprout", note = "Vegetable vendor", food = true, cuisine = "Vegetarian", },
        [69955698] = { label = "Darrah Anderson", note = "Fruit vendor", food = true, cuisine = "Fruit", },
        [48724657] = { label = "Janice Penia", note = "Bread vendor", food = true, cuisine = "Bakery", },
        [54715086] = { label = "Bo's Crab Shack", note = "Restaurant", food = true, cuisine = "Seafood", tables = 6, seats = 18, maxseats = 3, floors = 2, novendor = true, }, 
        [59942232] = { label = "Col. Tenders", food = true, cuisine = "Fried chicken (to go)", note = "Sells ancona chicken pet", animals = 3, }, 
        [55801829] = { label = "Honey market stall", food = true, novendor = true, tables = 1, seats = 2, maxseats = 2, empty = true, },
        [64563139] = { label = "Quimby's Chowder", note = "Soup kitchen; tables are on either side along the road", food = true, tables = 3, seats = 7, maxseats = 3, cuisine = "Soup", novendor = true, },
        [70575989] = { label = "That's a Moray", note = "When the moon hits your eye like a big pizza pie", food = true, cuisine = "Seafood", novendor = true, tables = 2, seats = 5, maxseats = 3, }, 
        [65665874] = { label = "Clams & Cockles", food = true, novendor = true, seats = 9, tables = 4, maxseats = 3, cuisine = "Seafood", },
        [55576249] = { label = "Goldman's Cafe", food = true, novendor = true, seats = 13, tables = 3, maxseats = 3, cuisine = "Bakery, desserts", floors = 3, }, 
        [49877898] = { label = "Unity Square Fruit Stand", food = true, novendor = true, cuisine = "Fruit", },
        [75092175] = { label = "Fish Hawker", note = "Akua the Tortollan", food = true, cuisine = "Fish", },
        [76552131] = { label = "Stormsong Produce", note = "Hauke Hartford", food = true, cuisine = "Vegetables", },
        [72051184] = { label = "Tradewinds Food Court", food = true, cuisine = "Food court", tables = 2, maxseats = 4, seats = 16, novendor = true, note = "Apparently you can cook your own food", animals = 1, },
        [71281089] = { label = "Byron & Bros. Boralan B.B.Q.", food = true, cuisine = "Boralan barbeque", note = "'Cap'n' Byron Mehlsack, cooking trainer", },
        [70260831] = { label = "Produce Stand", food = true, novendor = true, note = "Empty", empty = true, cuisine = "Produce", },
        [70760878] = { label = "Sausage Stand", food = true, novendor = true, note = "Empty", empty = true, cuisine = "Sausages", },

        -- shops
        [75130760] = { label = "Big Mountain Mining Supply Company", shop = true, note = "Myra Cabot, mining trainer", },
        [74220712] = { label = "Whalgrene's Lab", shop = true, note = "Eric Whalgrene, alchemy trainer", },
        [73350682] = { label = "Inksprocket Inscriptions", shop = true, note = "Zooey Inksprocket, inscription trainer", },
        [73090895] = { label = "The Ironfist Forge", shop = true, note = "Grix 'Ironfists' Barlow, blacksmithing trainer", },
        [71000505] = { label = "Tradewinds Gardens", shop = true, note = "Declan Senal, herbalism trainer", }, 
        [74850286] = { label = "Tradewinds Waterfall", place = true, poi = true, },
        [73890602] = { label = "Alan's Freshwater Fishing", shop = true, note = "Alan Goyle, fishing trainer", },
        [68970882] = { label = "Hudson Archaeological", shop = true, note = "Jane Hudson, archaeology trainer", basement = true, tables = 3, seats = 16, maxseats = 6, floors = 2, },
        [73351116] = { label = "Maps, Scrolls, & Mysteries", shop = true, note = "Henrick Wyther, trade goods", },
        [75841309] = { label = "Kul Tiran Skins and Leathers", shop = true, note = "Camilla Dansky, skinning trainer; and Cassandra Brennor, leatherworking trainer", },
        [75031009] = { label = "Colton's Jewels", shop = true, note = "Samuel D. Colton III, jewelcrafting trainer", },
        [74231136] = { label = "Fairweather's Fine Enchantments", shop = true, note = "Emily Fairweather, enchanting trainer", },
        [76471091] = { label = "Tradewinds Tailors", shop = true, note = "Daniel Brineweaver, tailoring trainer", },
        [77301423] = { label = "Evenkeel's Engineered Marvels", shop = true, note = "Layla Evenkeel, engineer trainer", },
        [75531830] = { label = "South Seas Merchant", shop = true, note = "Garrett Elmendorf sells a little booze on the side, but mostly rope", },
        [68092229] = { label = "Vegetable Stand", shop = true, novendor = true, empty = true, note = "Empty", },
        [72951578] = { label = "Spice Vendor", shop = true, note = "Sara Bartlett, cooking supplies", },
        [72291621] = { label = "Fur Trader", shop = true, note = "'Risky' Liz Seminario, tailoring supplies", },
        [73541597] = { label = "Gadget Vendor", shop = true, note = "Miri Fiddlewizz", },
        [74021628] = { label = "Firearm Vendor", shop = true, note = "Patrick Markson", }, 
        [67824131] = { label = "Fiona's Wagon", shop = true, note = "Fiona the worgen", }, 
        [66594083] = { label = "Thrift Goods", shop = true, note = "Arwin Blakemore sells low-level gray clothing", },
        [66934110] = { label = "Amateur Potions", shop = true, note = "Alchemist Hart", },
        [67254190] = { label = "Merchant Woolhands", shop = true, novendor = true, note = "Grummle trader with an alpaca (ot for sale)", }, 
        [67984013] = { label = "Arcane Oddities", shop = true, note = "Magus Delitha, enchanting supplies", }, 
        [65663088] = { label = "Empty stall", shop = true, empty = true, note = "Behind scrollmaster Uro", }, 
        [66483814] = { label = "Fishing supplies", shop = true, note = "Jovani Gartside", }, 
        [65823283] = { label = "Spells & Scrolls", shop = true, note = "Scrollmaster Uro, up the stairs from lower level", }, 
        [69893645] = { label = "Strange Artifacts", shop = true, note = "Kalo the Tortollan", }, 
        [66972987] = { label = "Fjarnskaggl Trader", shop = true, note = "Enges the vrykul is currently out of fjarnskaggl", },
        [70701963] = { label = "Cobbler", shop = true, note = "Phil Gresham, will shine your shoes", seats = 1, },
        [71221747] = { label = "Drustvar Trader", shop = true, novendor = true, note = "Pottery from Drustvar", },
        [72571790] = { label = "General Goods", shop = true, note = "Ninette Shoames", },
        [56046838] = { label = "Dock 1 Exports", shop = true, note = "Overpriced home decor, general goods", seats = 6, tables = 1, maxseats = 4, bed = 1, }, 
        [57746707] = { label = "Barrel & Crate", note = "Container store", shop = true, },
        [50504951] = { label = "Annie Lacier", note = "Weapon vendor", shop = true, },
        [50185021] = { label = "Green's Alchemy and Potions", note = "Alchemy vendor", shop = true, },
      
        [50404675] = { label = "Ruff Waters", note = "Pet supplies", shop = true, animals = 28, beds = 1, seats = 2, tables = 1, maxseats = 1, floors = 2, },
        [52244747] = { label = "Scribes & Nobles", note = "Bookstore, famous writer Laurence E. Craft doing a signing outise", shop = true, beds = 1, seats = 2, tables = 1, floors = 2, atlas = "Class", scale = 1.25, },
        [57243420] = { label = "McGloin's Fish Hooks", note = "Fishing supplies", novendor = true, hostile = true, shop = true, },
        [55394714] = { label = "Black Market", note = "Madam Gosu, Black Market Liaison", hostile = true, shop = true, },
        [56114600] = { label = "Art Fence's Stall", note = "Unmarked, but plenty of paintings", hostile = true, empty = true, novendor = true, shop = true, },
        [56674682] = { label = "Tricky's Nick's Stall", note = "Shady dealer (sells smuggled brutosaurs)", hostile = true, shop = true, },
        [54764156] = { label = "Bishops, Rooks, and Prawns", note = "Magic shop", hostile = true, empty = true, floors = 2, beds = 1, shop = true, },
        [49944166] = { label = "Beared Barrel Brewing Co.", note = "Brewery", floors = 1, closed = true, tables = 1, seats = 2, maxseats = 2, },
        [46083998] = { label = "Burnie's Smithey", note = "Blacksmithing vendor, anvil, forge", shop = true, },
        [59962001] = { label = "Ashvane Trader", shop = true, novendor = true, },
        [56022291] = { label = "Ashvane Trader", shop = true, novendor = true, },
        [56832278] = { label = "Empty market stall", shop = true, empty = true, },
        [57951527] = { label = "Algersons & Sons Lumber Co.", shop = true, novendor = true, }, 
        [60981690] = { label = "Poole's Cutting", shop = true, tables = 1, seats = 2, maxseats = 2, novendor = true, note = "Upstairs", },
        [49194980] = { label = "Megan Pescar", note = "Fishing vendor", shop = true, },
        [74717066] = { label = "Streetside Hawker", shop = true, novendor = true, note = "He advertises his wares but has none for sale", },
        [73726654] = { label = "Conestoga Wagons", shop = true, },
        [75756875] = { label = "Mariner's Row Fish & Tackle", shop = true, novendor = true, note = "Apparently they have a bad case of crabs", desks = 1, seats = 3, floors = 2, tables = 1, maxseats = 2, },
        [72067108] = { label = "Braddock & Son's Ladder Co.", shop = true, desks = 2, seats = 2, }, 
        [70256607] = { label = "Lost at Sea", note = "Map store", shop = true, floors = 2, beds = 2, desks = 3, },
        [71806348] = { label = "Combs & Morris Packing Supplies", shop = true, novendor = true, note = "I've seen kids do it", },
        [65086446] = { label = "Baubles, Bobbers, & Beyond", shop = true, novendor = true, hostile = true, },
        [69495626] = { label = "General Goods", shop = true, note = "Bruce Morales", },
        [56096506] = { label = "Tucker's Toys", shop = true, note = "Toy store", }, 

        -- basements
        [46344635] = { label = "Cold room", note = "Basement ice room (brr!)", basement = true, empty = true, },
        [58166087] = { label = "Fireside Anchors (wine cellar)", basement = true, },
        [52367807] = { label = "Dori's Cellar", basement = true, animals = 1, note = "A small dog named Dori wanders here", },
        [70168550] = { label = "Monastery Cellar", basement = true, hostile = true, },
        [61597786] = { label = "Monastery Cellar", basement = true, hostile = true, },
        [66978038] = { label = "Tidesage Archives", basement = true, hostile = true, },

        [71828476] = { label = "Brazier", statue = true, hostile = true, poi = true, },
        [62087688] = { label = "Brazier", statue = true, hostile = true, poi = true, },
        [63957573] = { label = "Fountain", statue = true, hostile = true, poi = true, },
        [70258172] = { label = "Brazier", statue = true, hostile = true, poi = true, },
        [71148213] = { label = "Monastery Building", hostile = true, basement = true, misc = true, floors = 2, empty = true, tables = 2, seats = 11, maxseats = 6, },
        [69508811] = { label = "Brazier", statue = true, hostile = true, poi = true, },
        [66168511] = { label = "Tentacled Sculpture", statue = true, hostile = true, poi = true, },
        [67887440] = { label = "Tentacled Sculpture", statue = true, hostile = true, poi = true, },
        [65307821] = { label = "Open-Air Cathedral", place = true, poi = true, hostile = true, seats = 32, },
        [64048006] = { label = "Altar", place = true, poi = true, statue = true, hostile = true, },
        [63238124] = { label = "Monastery Tower", hostile = true, misc = true, basement = true, floors = 2, tables = 3, maxseats = 6, seats = 16, },
        -- official buildings
        [69721544] = { label = "Guildmaster's Office", official = true, desks = 1, seats = 3, tables = 1, maxseats = 2, floors = 2, },
        [71801428] = { label = "Ethereal Embassy", official = true, note = "Transmog and void storage", floors = 2, desks = 1, seats = 1, },
        [40896770] = { label = "Lord Admiral's Rest", poi = true, note = "Graves of Daelin, Derek, and Tandred Proudmoore", statue = true, }, 
        [68053809] = { label = "Stocks", official = true, empty = true, note = "They're currently empty", seats = 6, }, 
        [67982239] = { label = "Harbormaster's Office", official = true, },
        [76412009] = { label = "Inspector's Desk", official = true, },
        [44463625] = { label = "Proudmoore Barracks (Training Yard)", note = "Horde quest area", official = true, tables = 3, seats = 4, maxseats = 2, desks = 1, floors = 2, },
        [42123773] = { label = "Proudmoore Barracks (Sleeping Quarters)", note = "Horde quest area", official = true, tables = 2, seats = 8, maxseats = 4, desks = 1, beds = 9, },
        [39983830] = { label = "Proudmoore Barracks (The Brig Jail Yard)", note = "Horde quest area", official = true, beds = 6, tables = 6, seats = 11, maxseats = 2, floors = 2, },
        [38143815] = { label = "Proudmoore Barracks (Mess Hall)", basement = true, official = true, tables = 3, seats = 8, maxseats = 2, bar = true, novendor = true, },
        [64532124] = { label = "Security post tent", official = true, desks = 1, seats = 1, note = "Captain Donnel's tent", },
        [77507529] = { label = "Boralus guard training grounds", official = true, note = "Players can't use these training dummies", },
        [76437712] = { label = "Department of Mariner's Vessels", official = true, note = "They seem to handle the mail, espite being disorganized", desks = 1 , seats = 2, floors = 2, },
        [77657262] = { label = "Inspector's tent", official = true, }, 
        [61766082] = { label = "Crosswind Ferry Registrar's Office", note = "They handle postal service", official = true, seats = 1, },
        [49178541] = { label = "The Assemblage of Houses", note = "Large amphitheater", official = true, }, 
        [77332469] = { label = "Dockmaster's Office", note = "Kate Banks", official = true, desks = 1, seats = 7, tables = 1, maxseats = 2, },
        [75551918] = { label = "Tradewinds Counting House", note = "Bank (in-game)", official = true, atlas = "Banker", scale = 1.25, },

        -- proudmoore academy
        [35306987] = { label = "Entrance to Proudmoore Academy", official = true, place = true, }, 
        [31536393] = { label = "The Grand Map", official = true, place = true, },
        [31687052] = { label = "Erickson Hall", basement = true, misc = true, tables = 3, seats = 16, maxseats = 6, floors = 2, note = "Proudmoore Academy library", }, 
        [30186862] = { label = "Erickson Quad", poi = true, },
        [29026048] = { label = "Teaching Square", poi = true, note = "Instructor Alexander", place = true, seats = 4, },
        [28156569] = { label = "Main Lecture Hall", misc = true, seats = 4, desks = 4, note = "Commodore Altham", }, 
        [27516239] = { label = "Knot-Tying Classroom", misc = true, note = "Bring your Handbook of Knot Tying", }, 
        [26606235] = { label = "Navigation Classroom", misc = true, note = "Fleet Navigator Norrison", desks = 1, seats = 4, },
        [25666254] = { label = "Tidesage Classroom", misc = true, seats = 3, }, 
        [27586806] = { label = "Admirality Office", misc = true, closed = true, },
        [27926335] = { label = "Enrollment Line", misc = true, }, 
        [26847465] = { label = "Ramshackle Tower", misc = true, tables = 1, seats = 1, maxseats = 1, },
        [21447906] = { label = "Cadet's Pier", misc = true, },
        [27947514] = { label = "Obstacle Course", misc = true, note = "Follow the torches!", place = true, },
        [29818013] = { label = "The Shipwreck", bar = true, note = "For officers only", seats = 1, novendor = true, },
        [31698311] = { label = "Shipwreck Cave", bar = true, tables = 3, seats = 9, maxseats = 4, novendor = true, empty = true, },
        [31625958] = { label = "Daelin's Hall", misc = true, food = true, cuisine = "Seafood", novendor = true, },
        [34226389] = { label = "The Golden Bell", poi = true, statue = true, },
        [35445616] = { label = "Memorial to Admiral Waylon Stormsong", poi = true, statue = true, },
        [37585797] = { label = "Stormsong Courtyard", poi = true, place = true, },
        [36903787] = { label = "Drill Sergeant's Office", official = true, tables = 1, seats = 4, maxseats = 4, "Drill Sergeant Smithson", }, 

        -- points of interest
        [63152337] = { label = "City Pup", animals = 1, },
        [63662722] = { label = "Barn Cat", animals = 1, },
        [75750844] = { label = "Whiskey the dog", poi = true, animals = 1, note = "He sleeps unders the stairs", },
        [76991631] = { label = "Scrap-O-Matic 1000", poi = true, },
        [74071435] = { label = "Chronicler Toopa", poi = true, note = "Tortollan", },
        [46028034] = { label = "Boralus Crier", poi = true, note = "All the news you need to know", },
        [70742987] = { label = "Ritual book", poi = true, note = "The apple might be important", },
        [67492370] = { label = "Little Library", misc = true, },
        [70351790] = { label = "Sanctum of the Sages", note = "Portal room", poi = true, seats = 2, desks = 2, },
        [51075049] = { label = "Lemptheby's Auction House", note = "Auction house (not an in-game AH)", poi = true, 
                       atlas = "Auctioneer", scale = 1.25, },
        [64702884] = { label = "Harbor Barber", note = "Barber shop", floors = 2, seats = 10, beds = 1, tables = 1, maxseats = 1, poi = true, },
        [54364678] = { label = "Outhouses", note = "Connected to the Kelp Club", seats = 2, poi = true, },
        [61781962] = { label = "Gallows", note = "Two prisoners to be executed", poi = true, atlas = "DungeonSkull", scale = 1.25, },
        [81377480] = { label = "Side Path", note = "Access to the top of the wall", poi = true, atlas = "VignetteEventElite", scale = 1.25, },
        [73190081] = { label = "Path to spooky graveyard", poi = true, atlas = "VignetteEventElite", scale = 1.25, },
        [68426239] = { label = "Crosswind Commons", note = "Often hostile smugglers, birds, etc", poi = true, hostile = true, }, 
        [51585996] = { label = "Tiragarde Trader's Wagon", note = "It appears he's being cited by the guard", poi = true, }, 
        [66824380] = { label = "Side Corridor", note = "Access to Boralus Harbor", poi = true, atlas = "VignetteEventElite", scale = 1.25, },
        [61341209] = { label = "Broken bridge", poi = true, place = true, },
        [80448343] = { label = "Road to Bridgeport", poi = true, place = true, },
        [40025718] = { label = "Bridge to Proudmoore Barracks", poi = true, place = true, },
        [48851959] = { label = "Road to Hatherford", poi = true, place = true, },
        [39964542] = { label = "Bridge to Proudmoore Keep", poi = true, place = true, },
        [43743267] = { label = "Bridge to Hatherford", poi = true, place = true, }, 
        [57995696] = { label = "Bridge to Hook Point", poi = true, place = true, },
        [56935112] = { label = "Bridge to Upton Borough", poi = true, place = true, },
        [67311284] = { label = "Flaming Practice Dummies", poi = true, note = "Why are they on fire?", },
        [66091454] = { label = "Clandestine Table", poi = true, tables = 1, seats = 2, maxseats = 2, note = "Down on the lowest level", },
        [59942644] = { label = "Ashvane Company Yards", poi = true, place = true, },

        -- flightmasters
        [76677255] = { label = "Gryphon Master", note = "Nicolas Araujo", poi = true, atlas = "FlightMaster", scale = 1.25, },
        [47856532] = { label = "Gryphon Master", note = "Jessica Clarke", poi = true, atlas = "FlightMaster", scale = 1.25, },
        [67131496] = { label = "Gryphon Master", note = "Joan Weber", poi = true, atlas = "FlightMaster", scale = 1.25, },

        -- stables
        [64412579] = { label = "Stables", note = "No actual stablemaster, nor mounts for sale", poi = true, atlas = "Stablemaster", scale = 1.25, },
        [79017301] = { label = "Stables", note = "No actual stablemaster, nor mounts for sale", poi = true, atlas = "Stablemaster", scale = 1.25, },
        [47147087] = { label = "Stables", note = "No actual stablemaster, nor mounts for sale", poi = true, atlas = "Stablemaster", scale = 1.25, },
        [69731299] = { label = "Stables", note = "Leila Stafford, stable master", poi = true, atlas = "Stablemaster", scale = 1.25, },

        -- ships 
          -- super-large ship
        [05968882] = { label = "Admiralty Warship", note = "Commodore Rooke's flagship", floors = 5, decks = 4, atlas = "Ships_DreadnaughtA-Portrait", scale = 2.5, ship = true, shipsize = "LARGE", },
          -- large ships
        [69872716] = { label = "Wind's Redemption", note = "Alliance warship", official = true, ship = true, shipsize = "LARGE", atlas = "Ships_GalleonA-Map", scale = 2, },
        [69803302] = { label = "Empty ship", note = "Lacks furniture entirely", empty = true, floors = 2, ship = true, decks = 4, shipsize = "LARGE", },
        [46173383] = { label = "Docked privateer ship", note = "Large ship", floors = 2, tables = 3, maxseats = 3, seats = 11, bar = true, novendor = true, beds = 8, ship = true, decks = 4, shipsize = "LARGE", },
        [20445718] = { label = "Anchored academy ship", note = "Large ship", floors = 2, tables = 3, maxseats = 3, seats = 11, bar = true, novendor = true, beds = 8, ship = true, decks = 4, shipsize = "LARGE", empty = true, },
        [75068074] = { label = "Anchored privateer ship", note = "Large ship", floors = 2, tables = 3, maxseats = 3, seats = 11, bar = true, novendor = true, beds = 8, ship = true, decks = 4, shipsize = "LARGE", 
          claimed = true, 
          claims = { 
            { server = "MoonGuard-US", guild = "Boralus Merchant Marine",
              label = "The Steadfast", note = "Lead ship of the Boralus Merchant Marine", 
            },  -- [1]
          },
        }, 

          -- medium ships
        [55632928] = { label = "Ashvane ship", note = "Medium ship", closed = true, decks = 4, ship = true, shipsize = "MEDIUM", },
          -- small ships
        [53812139] = { label = "Ashvane ship", note = "Small ship, access from the Ravens Flock deck", closed = true, decks = 3, ship = true, shipsize = "SMALL", },
        [61466255] = { label = "Docked privateer ship", note = "Small ship", closed = true, decks = 3, ship = true, shipsize = "SMALL", }, 

          -- sailboats
        [58681220] = { label = "Trader's sailboat", ship = true, decks = 1, shipsize = "SAILBOAT", },
        [54253253] = { label = "Sailboat", note = "At water level", ship = true, hostile = true, empty = true, decks = 1, shipsize = "SAILBOAT", },
        [58587235] = { label = "Leaky Sailboat", note = "At water level", ship = true, empty = true, decks = 1, shipsize = "SAILBOAT", },
        [29588511] = { label = "Captain's Sailboat", ship = true, empty = true, decks = 1, shipsize = "SAILBOAT", }, 
        [64356946] = { label = "Monastery Sailboat", ship = true, decks = 1, hostile = true, empty = true, shipsize = "SAILBOAT", },
        [72657745] = { label = "Monastery Sailboat", ship = true, decks = 1, hostile = true, empty = true, shipsize = "SAILBOAT", },
        [72047745] = { label = "Monastery Docks", place = true, poi = true, hostile = true, }, -- not a boat
        --
          -- boats/rowboats/dinghy
        [54894152] = { label = "Dinghy", ship = true, decks = 1, note = "Contains crates", hostile = true, shipsize = "BOAT", },
        [53603318] = { label = "Dinghy", note = "At water level, crates", ship = true, hostile = true, decks = 1, shipsize = "BOAT", },
        [55142424] = { label = "Dinghy", note = "Contains Stormwind shield, weapons", ship = true, decks = 1, shipsize = "BOAT", },
        [74667706] = { label = "Dinghy", ship = true, decks = 1, note = "Contains sacks", shipsize = "BOAT", }, -- mariner's row, far south/west
        [59387096] = { label = "Deckhand's Dinghy", ship = true, decks = 1, shipsize = "BOAT", }, -- below pinky's
        [68636583] = { label = "Hoisted Dinghy", ship = true, decks = 1, note = "Out of the water", hostile = true, shipsize = "BOAT", }, -- Mariner's row 
        [76147677] = { label = "Crab trap boat", ship = true, decks = 1, shipsize = "BOAT", },
        [76627766] = { label = "Crab trap boat", ship = true, note = "Occupied by a Boralus sailor", decks = 1, shipsize = "BOAT", },
        [67311779] = { label = "Tied Dinghy", note = "Down at water level", empty = true, ship = true, decks = 1, shipsize = "BOAT", },
        [71392072] = { label = "Andy's Dinghy", note = "Down at water level", ship = true, decks = 1, shipsize = "BOAT", },
        [72542009] = { label = "Cargo Barge", note = "Down at water level", ship = true, decks = 1, shipsize = "BOAT", empty = true, },
        [56871352] = { label = "Lumber Barge", ship = true, decks = 1, shipsize = "BOAT", },
        [55481499] = { label = "Patrick's Food Barge", ship = true, decks = 1, shipsize = "BOAT", },
        [54731546] = { label = "Carmine Food Barge", ship = true, decks = 1, shipsize = "BOAT", },
        [74912424] = { label = "Cargo Barge", note = "Down at water level", ship = true, decks = 1, shipsize = "BOAT", empty = true, },
        [75652399] = { label = "Franklin's Dinghy", note = "At least he's not driving it", ship = true, decks = 1, shipsize = "BOAT", },
        [76332109] = { label = "Suspended Dinghy", note = "Held aloft by cranes, contains fruit", ship = true, decks = 1, shipsize = "BOAT", },

        -- landings
        [53835276] = { label = "Rolfe's barge landing", ship = true, decks = 1, shipsize = "LANDING", food = true, cuisine = "Fish", note = "Rolfe Braxton, fishmonger", },
        [47465054] = { label = "Rolfe's barge landing", ship = true, decks = 1, shipsize = "LANDING", food = true, cuisine = "Fish", note = "Rolfe Braxton, fishmonger", },
        [52963612] = { label = "Rolfe's barge landing", ship = true, decks = 1, shipsize = "LANDING", food = true, cuisine = "Fish", note = "Rolfe Braxton, fishmonger", },

        [77902544] = { label = "Departure point for The Relentless", ship = true, decks = 1, shipsize = "LANDING", atlas = "ShipMissionIcon-SiegeA-Map", scale = 1.7, },

        [66925136] = { label = "Canal ferry landing", ship = true, decks = 1, shipsize = "LANDING", note = "Ferry to Dampwick Ward", },
        [66724657] = { label = "Canal ferry landing", ship = true, decks = 1, shipsize = "LANDING", note = "Ferry to Mariner's Row", }, 
        [49721741] = { label = "Inspector's Dinghy", ship = true, decks = 1, shipsize = "BOAT", empty = true, },

        -- tidesage doomspeakers
        [64263656] = { label = "Tidesage Doomspeaker", poi = true, atlas = "Vehicle-TempleofKotmogu-CyanBall", scale = 1.25, },
        [63043164] = { label = "Tidesage Doomspeaker", poi = true, atlas = "Vehicle-TempleofKotmogu-CyanBall", scale = 1.25, },
        [60043420] = { label = "Tidesage Doomspeaker", poi = true, atlas = "Vehicle-TempleofKotmogu-CyanBall", scale = 1.25, },
        [62563898] = { label = "Tidesage Doomspeaker", poi = true, atlas = "Vehicle-TempleofKotmogu-CyanBall", scale = 1.25, },
        [59054336] = { label = "Tidesage Doomspeaker", poi = true, atlas = "Vehicle-TempleofKotmogu-CyanBall", scale = 1.25, },
        [56043871] = { label = "Tidesage Doomspeaker", poi = true, atlas = "Vehicle-TempleofKotmogu-CyanBall", scale = 1.25, },

        -- fountains, statues, etc
        [52686426] = { label = "Upton Fountain", poi = true, statue = true, }, 
        [51797732] = { label = "Memorial Fountain", poi = true, statue = true, },
        [48126829] = { label = "Two Lanterns Fountain", poi = true, statue = true, },
        [48105957] = { label = "Candlelight Memorial", poi = true, statue = true, },
        [44737112] = { label = "Ship's Bell Statue", poi = true, note = "Possibly from The Liberty", statue = true, },
        [47877846] = { label = "Statue of Lord Admiral Daelin Proudmoore", poi = true, statue = true, }, 
        [45557357] = { label = "Captain James Ashvane Memorial Fountain", poi = true, statue = true, },
        [34487413] = { label = "Park Fountain", poi = true, statue = true, },
        [36387214] = { label = "'The Ambassador'", poi = true, note = "Statue of a large cannon", statue = true, }, 
        [73101737] = { label = "Harbor Fountain", poi = true, statue = true, },

        -- graveyards

        [32897272] = { label = "Proudmoore Keep Graveyard", poi = true, graveyard = true, },

        -- locations
        [52607388] = { label = "Family Park", poi = true, place = true, note = "The Clarks are picnicking here with their four kids", },
        [45086261] = { label = "Proudmoore Keep Outer Courtyard", poi = true, official = true, place = true, },
        [42776258] = { label = "Proudmoore Keep Front Doors", poi = true, closed = true, official = true, place = true, },
        [49027458] = { label = "Unity Square", poi = true, place = true, },
        [44838736] = { label = "Garden Gazebo", poi = true, place = true, }, 
        [40128374] = { label = "Proudmoore Keep Gardens", poi = true, place = true, },
        [41837872] = { label = "Entrance to the Hedge Maze", note = "Don't get lost!", poi = true, },
        [33568042] = { label = "Artist Kuko Cai", note = "She has a number of paintings here", animals = 2, poi = true, tables = 1, seats = 1, maxseats = 1, }, 
        [35107657] = { label = "Cadets' Park", poi = true, place = true, }, 
        [35667562] = { label = "Childrens' Park", poi = true, animals = 1, note = "Birthday party in the park", place = true, },

        -- warehouses
        [61833137] = { label = "Unnamed warehouse", empty  = true, misc = true, },
        [56094387] = { label = "Unnamed warehouse", empty  = true, misc = true, },
        [60602388] = { label = "Ashvane warehouse", floors = 2,    misc = true, },
        [56522007] = { label = "Ashvane warehouse", floors = 2,    misc = true, },

        -- unidentified open buildings
        [63383863] = { label = "Unmarked building", hostile = true, floors = 3, desks = 1, tables = 2, seats = 7, maxseats = 4, misc = true, }, 
        [52864033] = { label = "Unnamed building", note = "Possibly an office", floors = 2, empty = true, desks = 1, seats = 3, maxseats = 2, tables = 1, hostile = true, claimed = true, misc = true, 
                      claims = { 
                         { player = "Oraibi", 
                           server = "MoonGuard-US", 
                           label = "Boralus Legal Aid", 
                           note = "Legal office", }, 
                         }, },
        [60184303] = { label = "Tiny unidentified building", empty = true, hostile = true, note = "Contains broken furniture, spiral staircase outside", misc = true, },
        [48203931] = { label = "Unmarked building", note = "Octopus tentacles outside", floors = 2, desks = 1, seats = 1, animals = 1, beds = 1, misc = true, },
        -- [58361255] = { label = "Unmarked dock building", beds = 1, empty = true, misc = true, },
        [58361255] = { label = "Unmarked building", desks = 2, seats = 3, beds = 1, misc = true, floors = 3, note = "Two men on the top balcony watch the monastery", },
        [57116545] = { label = "Reading Lounge", note = "Near Fireside Anchors", seats = 4, misc = true, },
        [52887562] = { label = "Nursery", misc = true, },
        [46967393] = { label = "Unity Square Building", seats = 9, beds = 1, basement = true, tables = 1, maxseats = 5, floors = 2, note = "A Proudmoore officer is sitting at a table on the second floor", }, 
        [50728265] = { label = "Assemblage Side Hall (North)", seats = 6, tables = 2, maxseats = 4,misc = true, }, 
        [46228576] = { label = "Assemblage Side Hall (South)", seats = 3, tables = 1, maxseats = 3, misc = true, }, 
        [44558111] = { label = "Unity Square Library", basement = true, tables = 2, seats = 8, floors = 2, maxseats = 6, misc = true, },
        [66632379] = { label = "Empty Stall", shop = true, novendor = true, empty = true, },
        [49981852] = { label = "Inspector's Shack", official = true, empty = true, desks = 1, seats = 1, }, 
        [72257920] = { label = "Monastery Wharf Shack", empty = true, hostile = true, floors = 2, },
        [61578397] = { label = "Underwater Tunnel", basement = true, hostile = true, place = true, poi = true, },
        [55749106] = { label = "Ominous Altar", note = "Take the underwater tunnel to get here", poi = true, statue = true, },

        -- homes
        [72786402] = { label = "Julie Auklight's House", animals = 3, note = "Can access the top of the wall from the 3rd floor", floors = 3, desks = 1, seats = 3, tables = 1, beds = 1, maxseats = 1, misc = true, },
        [54077146] = { label = "Catty Cathy's", misc = true, note = "Crazy cat lady", animals = 23, },

        -- closed buildings
        [67752670] = { label = "Unmarked building",     closed = true, misc = true, note = "This building has no doorsat all", },
        [68262358] = { label = "Unmarked building",     closed = true, misc = true, },
        [69391697] = { label = "Unmarked building",     closed = true, misc = true, },
        [68361984] = { label = "Unmarked building",     closed = true, misc = true, },
        [63763635] = { label = "Unmarked building",     closed = true, misc = true, },
        [64324214] = { label = "Unmarked building",     closed = true, misc = true, },
        [75750750] = { label = "Unmarked building",     closed = true, misc = true, },
        [64153951] = { label = "Unmarked building",     closed = true, misc = true, },
        [75347654] = { label = "Unmarked building",     closed = true, misc = true, },
        [68231092] = { label = "Unmarked building",     closed = true, misc = true, },
        [74277017] = { label = "Unmarked building",     closed = true, misc = true, },
        [67996135] = { label = "Unmarked building",     closed = true, misc = true, },
        [66426279] = { label = "Unmarked building",     closed = true, misc = true, },
        [67236071] = { label = "Unmarked building",     closed = true, misc = true, },
        [70516994] = { label = "Unmarked building",     closed = true, misc = true, },
        [54706307] = { label = "Unmarked building",     closed = true, misc = true, },
        [67105734] = { label = "Unmarked building",     closed = true, misc = true, },
        [49077011] = { label = "Unmarked building",     closed = true, misc = true, },
        [60464378] = { label = "Unmarked building",     closed = true, hostile = true, misc = true, },
        [57424236] = { label = "Unmarked building",     closed = true, hostile = true, misc = true, },
        [61723582] = { label = "Unmarked building",     closed = true, hostile = true, misc = true, },
        [63344024] = { label = "Unmarked building",     closed = true, hostile = true, misc = true, },
        [65764002] = { label = "Unmarked building",     closed = true, note = "Upstairs", misc = true, },
        [59473282] = { label = "Unmarked sausage shop", closed = true, hostile = true, misc = true, },

        -- closed named buildings
        [53414887] = { label = "Steamed Hamhocks",   closed = true, misc = true, shop = true, },
        [58714373] = { label = "The Muddy Rudder",   closed = true, bar = true, novendor = true, hostile = true, misc = true, },
        [62533336] = { label = "Chuck's",            note = "Cheese shop", closed = true, misc = true, },
        [63173412] = { label = "The Cracked Barrel", note = "Cheese shop", closed = true, misc = true, },
        [57953263] = { label = "Ashvane Laundry",    closed = true, hostile = true, misc = true, },
        [50747271] = { label = "Perfect Storm Brewing", misc = true, closed = true, },
        [50127391] = { label = "Stern Masts", misc = true, closed = true, note = "It's unclear what they do here", }, 
          
    }, -- /Boralus 
}
