local myname, ns = ...

ns.defaults = {
    profile = {
        show_on_city = true,
        show_on_minimap = true,

        show_bars = true,
        show_food = true,
        show_shops = false,
        show_ships = true,
        show_official = false,
        show_basements = false,
        show_poi = true,
        show_misc = false,

        show_beds = false,
        show_animals = false,
--        show_claimed = false,
        
        hide_closed = true,
        hide_empty = false,
        hide_novendor = true,
        icon_scale = 1.0,
        icon_alpha = 1.0,
    },
    char = {
        hidden = {
            ['*'] = {},
        },
    },
}

local GetAddOnMetadata = GetAddOnMetadata;

ns.options = {
    type = "group",
    name = myname:gsub("HandyNotes_", ""),
    desc = GetAddOnMetadata(myname, "Notes"),
    get = function(info) return ns.db[info[#info]] end,
    set = function(info, v)
        ns.db[info[#info]] = v
        ns.HL:SendMessage("HandyNotes_NotifyUpdate", myname:gsub("HandyNotes_", ""))
    end,
    args = {
        icon = {
            type = "group",
            name = "Icon settings",
            inline = true,
            order = 100,
            args = {
                desc = {
                    name = "These settings control the look and feel of the icon.",
                    type = "description",
                    order = 0,
                },
                icon_scale = {
                    type = "range",
                    name = "Icon Scale",
                    desc = "The scale of the icons",
                    min = 0.25, max = 2, step = 0.01,
                    order = 20,
                },
                icon_alpha = {
                    type = "range",
                    name = "Icon Alpha",
                    desc = "The alpha transparency of the icons",
                    min = 0, max = 1, step = 0.01,
                    order = 30,
                },
                show_on_city = {
                    type = "toggle",
                    name = "Boralus Map",
                    desc = "Show icons on city map",
                    order = 40,
                },
                show_on_minimap = {
                    type = "toggle",
                    name = "Minimap",
                    desc = "Show icons on the minimap",
                    order = 50,
                },
            },
        },
        show = {
            type = "group",
            name = "Locations to display",
            inline = true,
            order = 200,
            args = {
                show_bars = {
                    type = "toggle",
                    name = "Bars/Taverns",
                    desc = "Show bars and taverns",
                    order = 100,
                },
                show_food = {
                    type = "toggle",
                    name = "Food",
                    desc = "Show restaurants, food vendors, and others places to eat",
                    order = 110,
                },
                show_shops = {
                    type = "toggle",
                    name = "Shopping",
                    desc = "Show places you can go shopping",
                    order = 120,
                },
                show_ships = {
                    type = "toggle",
                    name = "Ships",
                    desc = "Show ships and boats",
                    order = 140,
                }, 
                show_official = {
                    type = "toggle",
                    name = "Official Buildings",
                    desc = "Show government, military, and guild buildings",
                    order = 150,
                },
                show_basements = {
                    type = "toggle",
                    name = "Basements",
                    desc = "Show basements, cellars, and cold rooms",
                    order = 160,
                },
                show_beds = {
                    type  = "toggle",
                    name  = "Beds",
                    desc  = "Show locations that have empty beds for sleeping",
                    order = 170,
                },
                show_poi = {
                    type  = "toggle",
                    name  = "Points of Interest",
                    desc  = "Show other points of interest",
                    order = 180,
                },
                show_animals = {
                    type  = "toggle",
                    name  = "Cats and Dogs",
                    desc  = "Show pettable animals",
                    order = 190,
                },
                show_misc = {
                    type  = "toggle",
                    name  = "Miscellaneous",
                    desc  = "Show other buildings, including unidentified",
                    order = 190,
                },
            },
        },
        hide = {
            type = "group",
            name = "Exceptions: Don't show the following.",
            inline = true,
            order = 300,
            args = {
                hide_empty = {
                    type = "toggle",
                    name = "Empty Buildings",
                    desc = "Only show buildings with people in them",
                    order = 130,
                },
                hide_closed = {
                    type = "toggle",
                    name = "Closed Buildings",
                    desc = "Only show buildings that have open doors",
                    order = 140,
                }, 
                hide_novendor = {
                    type = "toggle",
                    name = "No Vendor",
                    desc = "Only show shops or bars that have a vendor that can be interacted with",
                    order = 150,
               },
            },
        },
--        claim = {
--            type = "group",
--            name = "Roleplaying Claims",
--            inline = true,
--            order = 400,
--            args = {
--                show_claimed = {
--                    type  = "toggle",
--                    name  = "Claimed",
--                    desc  = "Always show buildings claimed by RPers",
--                    order = 190,
--                }, 
--            },
--        },

    },
}

local player_name = UnitName("player")

ns.should_show_point = function(coord, point, currentZone, isMinimap)

    local show = false;

    -- try to find a reason to show it
    if    (point.poi      and ns.db.show_poi)
       or (point.ship     and ns.db.show_ships)
       or (point.official and ns.db.show_official)
       or (point.basement and ns.db.show_basements)
       or (point.food     and ns.db.show_food)
       or (point.bar      and ns.db.show_bars)
       or (point.shop     and ns.db.show_shops)
--       or (point.claimed  and ns.db.show_claimed)
       or (point.beds     and ns.db.show_beds)
       or (point.animals  and ns.db.show_animals)
       or (point.misc     and ns.db.show_misc)
       then show = true;
    end; -- if/then

    -- try to find a reason to not show it
    if show and point.empty    and ns.db.hide_empty    then show = false end;
    if show and point.closed   and ns.db.hide_closed   then show = false end;
    if show and point.novendor and ns.db.hide_novendor then show = false end;

       -- but even if it's empty or closed we still want to show it if it's claimed or a ship
 --   if not show and point.claimed and ns.db.show_claimed then show = true end; -- if/then
    if not show and point.ship    and ns.db.show_ships   then show = true end; -- if/then

       -- only show if we're on the map or minimap or whatever
    if isMinimap and not ns.db.show_on_minimap 
       then show = false
       elseif not isMinimap and not ns.db.show_on_city 
       then show = false
    end; -- if/then/elseif/then

    return show;
end
