local myname, ns = ...

local HandyNotes = LibStub("AceAddon-3.0"):GetAddon("HandyNotes")
local HL = LibStub("AceAddon-3.0"):NewAddon(myname, "AceEvent-3.0")
-- local L = LibStub("AceLocale-3.0"):GetLocale(myname, true)
ns.HL = HL

local debugf = tekDebug and tekDebug:GetFrame(myname:gsub("HandyNotes_", ""))
local function Debug(...) if debugf then debugf:AddMessage(string.join(", ", tostringall(...))) end end
ns.Debug = Debug

local next = next
local GameTooltip = GameTooltip
local WorldMapTooltip = WorldMapTooltip
local HandyNotes = HandyNotes

local cache_tooltip = CreateFrame("GameTooltip", "HNBattleTreasuresTooltip")

cache_tooltip:AddFontStrings(
    cache_tooltip:CreateFontString("$parentTextLeft1", nil, "GameTooltipText"),
    cache_tooltip:CreateFontString("$parentTextRight1", nil, "GameTooltipText")
)
local name_cache = {}

local default_texture, 
      bar_texture, 
      food_texture, 
      shop_texture, 
      poi_texture, 
      official_texture, 
      empty_texture, 
      statue_texture,
      place_texture,
      basement_texture;

local misc_hostile_texture, 
      misc_friendly_texture;
      
local ship_large_texture, 
      ship_medium_texture, 
      ship_small_texture, 
      ship_sailboat_texture, 
      ship_boat_texture, 
      ship_barge_texture, 
      ship_landing_texture;

local icon_cache = {}

local trimmed_icon = function(texture)
    if not icon_cache[texture] then
        icon_cache[texture] = {
            icon = texture,
            tCoordLeft = 0.1,
            tCoordRight = 0.9,
            tCoordTop = 0.1,
            tCoordBottom = 0.9,
        }
    end
    return icon_cache[texture]
end

local atlas_texture = function(atlas, scale)
    local texture, _, _, left, right, top, bottom = GetAtlasInfo(atlas)
    return {
        icon = texture,
        tCoordLeft = left,
        tCoordRight = right,
        tCoordTop = top,
        tCoordBottom = bottom,
        scale = scale or 1,
    }
end

local function work_out_label(point)
    local fallback

    if point.label and point.hostile 
        then return "|cffff0000" .. point.label .. "|r"
        elseif point.label then return point.label
        end

    return fallback or UNKNOWN
end

local function work_out_texture(point)
    if point.atlas then
        if not icon_cache[point.atlas] then
            icon_cache[point.atlas] = atlas_texture(point.atlas, point.scale)
        end
        return icon_cache[point.atlas]
    end

    if point.statue and ns.db.show_poi then
        if not statue_texture then
           statue_texture = atlas_texture("MantidTower", 1.6)
        end
        return statue_texture
    end

    if point.place and ns.db.show_poi then
        if not place_texture then
           place_texture = atlas_texture("Vehicle-TempleofKotmogu-OrangeBall", 1.5)
        end
        return place_texture
    end

    if point.poi and ns.db.show_poi  then
        if not poi_texture then
            poi_texture = atlas_texture("Vehicle-TempleofKotmogu-PurpleBall", 1.5)
        end
        return poi_texture
    end

    if point.ship and ns.db.show_ships then
       if point.shipsize == "LARGE" 
          then if not ship_large_texture 
                      then ship_large_texture = atlas_texture("Ships_DreadnaughtA-Map", 4) 
                      end
               return ship_large_texture
       elseif point.shipsize == "MEDIUM"
          then if not ship_medium_texture 
                      then ship_medium_texture = atlas_texture("Ships_Dreadnaught-Map", 3) 
                      end
               return ship_medium_texture
       elseif point.shipsize == "SMALL"
          then if not ship_small_texture 
                      then ship_small_texture = atlas_texture("Ships_GalleonA-Map", 2.5) 
                      end
               return ship_small_texture
       elseif point.shipsize == "SAILBOAT"
          then if not ship_sailboat_texture 
                      then ship_sailboat_texture = atlas_texture("Ships_TroopTransport-Map", 2) 
                      end
               return ship_sailboat_texture
       elseif point.shipsize == "BOAT"
          then if not ship_boat_texture 
                      then ship_boat_texture = atlas_texture("Ships_CarrierA-Map", 2) 
                      end
               return ship_boat_texture
       elseif point.shipsize == "LANDING"
          then if not ship_landing_texture 
                      then ship_landing_texture = atlas_texture("ShipMissionIcon-SiegeA-Map", 2)
                      end
               return ship_landing_texture
       end;
    end

    if point.official and ns.db.show_official then
        if not official_texture then
            official_texture = atlas_texture("ShipMissionIcon-Training-MapBadge", 1.5)
        end
        return official_texture
    end

    if point.basement and ns.db.show_basements then
        if not basement_texture then
         basement_texture = atlas_texture("MiniMap-PositionArrowDown", 2.5)
        end
        return basement_texture
    end

    if point.shop and ns.db.show_shops then
        if not shop_texture then
            shop_texture = atlas_texture("poi-town", 1.25)
        end
        return shop_texture
    end

    if point.bar and ns.db.show_bars then
       if not bar_texture then
          bar_texture = atlas_texture("PortalRed", 2.5)
          end
       return bar_texture
    end;

    if point.food and ns.db.show_food then
        if not food_texture then
            food_texture = atlas_texture("Food", 1.5)
        end
        return food_texture
    end

    if point.misc and ns.db.show_misc and not point.hostile then
       if not misc_friendly_texture then
          misc_friendly_texture = atlas_texture("MonsterFriend", 1.75)
       end
       return misc_friendly_texture
    end

    if point.misc and ns.db.show_misc and point.hostile then
       if not misc_hostile_texture then
          misc_hostile_texture = atlas_texture("MonsterEnemy", 1.75)
       end
       return misc_hostile_texture
    end

    if not default_texture then
        default_texture = atlas_texture("GreenCross", 1.5)
    end
    return default_texture

end

local get_point_info = function(point)
    if point then
        local label = work_out_label(point)
        local icon = work_out_texture(point)
        local category = "rpspot"
        return label, icon, category, point.quest, point.faction, point.scale, point.alpha or 1
    end
end

local get_point_info_by_coord = function(uiMapID, coord)
    return get_point_info(ns.points[uiMapID] and ns.points[uiMapID][coord])
end

local function handle_tooltip(tooltip, point)
    if point then
        -- major:
        tooltip:AddLine(work_out_label(point))

--         if point.follower then
--             local follower = C_Garrison.GetFollowerInfo(point.follower)
--             if follower then
--                 local quality = BAG_ITEM_QUALITY_COLORS[follower.quality]
--                 tooltip:AddDoubleLine(REWARD_FOLLOWER, follower.name,
--                     0, 1, 0,
--                     quality.r, quality.g, quality.b
--                 )
--                 tooltip:AddDoubleLine(follower.className, UNIT_LEVEL_TEMPLATE:format(follower.level))
--             end
--         end
-- 
--         if point.currency then
--             local name
--             if point.currency == 'ARTIFACT' then
--                 name = ARTIFACT_LABEL
--             else
--                 name = GetCurrencyInfo(point.currency)
--             end
--             tooltip:AddDoubleLine(CURRENCY, name or point.currency)
--         end
-- 
--         if point.achievement then
--             local _, name, _, complete = GetAchievementInfo(point.achievement)
--             tooltip:AddDoubleLine(BATTLE_PET_SOURCE_6, name or point.achievement,
--                 nil, nil, nil,
--                 complete and 0 or 1, complete and 1 or 0, 0
--             )
--             if point.criteria then
--                 local criteria, _, complete = GetAchievementCriteriaInfoByID(point.achievement, point.criteria)
--                 tooltip:AddDoubleLine(" ", criteria,
--                     nil, nil, nil,
--                     complete and 0 or 1, complete and 1 or 0, 0
--                 )
--             end
--         end
-- 
        if point.note then
            tooltip:AddLine(point.note, nil, nil, nil, true)
        end
-- 
--         if point.quest and ns.db.tooltip_questid then
--             local quest = point.quest
--             if type(quest) == 'table' then
--                 quest = string.join(", ", unpack(quest))
--             end
--             tooltip:AddDoubleLine("QuestID", quest or UNKNOWN)
--         end
-- 
    else
        tooltip:SetText(UNKNOWN)
    end
    tooltip:Show()
end

local handle_tooltip_by_coord = function(tooltip, uiMapID, coord)
    return handle_tooltip(tooltip, ns.points[uiMapID] and ns.points[uiMapID][coord])
end

---------------------------------------------------------
-- Plugin Handlers to HandyNotes
local HLHandler = {}
local info = {}

function HLHandler:OnEnter(uiMapID, coord)
    local tooltip = self:GetParent() == WorldMapFrame:GetCanvas() and WorldMapTooltip or GameTooltip
    if self:GetCenter() > UIParent:GetCenter() then -- compare X coordinate
        tooltip:SetOwner(self, "ANCHOR_LEFT")
    else
        tooltip:SetOwner(self, "ANCHOR_RIGHT")
    end
    handle_tooltip_by_coord(tooltip, uiMapID, coord)
end

local function createWaypoint(button, uiMapID, coord)
    if TomTom then
        local x, y = HandyNotes:getXY(coord)
        TomTom:AddWaypoint(uiMapID, x, y, {
            title = get_point_info_by_coord(uiMapID, coord),
            persistent = nil,
            minimap = true,
            world = true
        })
    end
end

local function hideNode(button, uiMapID, coord)
    ns.hidden[uiMapID][coord] = true
    HL:Refresh()
end

local function closeAllDropdowns()
    CloseDropDownMenus(1)
end

do
    local currentZone, currentCoord
    local function generateMenu(button, level)
        if (not level) then return end
        wipe(info)
        if (level == 1) then
            -- Create the title of the menu
            info.isTitle      = 1
            info.text         = "HandyNotes - " .. myname:gsub("HandyNotes_", "")
            info.notCheckable = 1
            UIDropDownMenu_AddButton(info, level)
            wipe(info)

            if TomTom then
                -- Waypoint menu item
                info.text = "Create waypoint"
                info.notCheckable = 1
                info.func = createWaypoint
                info.arg1 = currentZone
                info.arg2 = currentCoord
                UIDropDownMenu_AddButton(info, level)
                wipe(info)
            end

            -- Close menu item
            info.text         = "Close"
            info.func         = closeAllDropdowns
            info.notCheckable = 1
            UIDropDownMenu_AddButton(info, level)
            wipe(info)
        end
    end
    local HL_Dropdown = CreateFrame("Frame", myname.."DropdownMenu")
    HL_Dropdown.displayMode = "MENU"
    HL_Dropdown.initialize = generateMenu

    function HLHandler:OnClick(button, down, uiMapID, coord)
        currentZone = uiMapID
        currentCoord = coord
        -- given we're in a click handler, this really *should* exist, but just in case...
        local point = ns.points[currentZone] and ns.points[currentZone][currentCoord]
        if button == "RightButton" and not down then
            ToggleDropDownMenu(1, nil, HL_Dropdown, self, 0, 0)
        end
    end
end

function HLHandler:OnLeave(uiMapID, coord)
    if self:GetParent() == WorldMapFrame:GetCanvas() then
        WorldMapTooltip:Hide()
    else
        GameTooltip:Hide()
    end
    ShoppingTooltip1:Hide()
end

do
    -- This is a custom iterator we use to iterate over every node in a given zone
    local currentZone, isMinimap
    local function iter(t, prestate)
        if not t then return nil end
        local state, value = next(t, prestate)
        while state do -- Have we reached the end of this zone?
            if value and ns.should_show_point(state, value, currentZone, isMinimap) then
                local label, icon, _, _, _, scale, alpha = get_point_info(value)
                scale = (scale or 1) * (icon and icon.scale or 1) * ns.db.icon_scale
                return state, nil, icon, scale, ns.db.icon_alpha * alpha
            end
            state, value = next(t, state) -- Get next data
        end
        return nil, nil, nil, nil
    end
    local function UnitHasBuff(unit, spellid)
        local buffname = GetSpellInfo(spellid)
        for i = 1, 40 do
            local name = UnitBuff(unit, i)
            if not name then
                -- reached the end, probably
                return
            end
            if buffname == name then
                return UnitBuff(unit, i)
            end
        end
    end
    function HLHandler:GetNodes2(uiMapID, minimap)
        Debug("GetNodes2", uiMapID, minimap)
        currentZone = uiMapID
        isMinimap = minimap
        if minimap and ns.map_spellids[uiMapID] then
            if ns.map_spellids[mapFile] == true then
                return iter
            end
            if UnitHasBuff("player", ns.map_spellids[mapFile]) then
                return iter
            end
        end
        return iter, ns.points[uiMapID], nil
    end
end

---------------------------------------------------------
-- Addon initialization, enabling and disabling

function HL:OnInitialize()
    -- Set up our database
    self.db = LibStub("AceDB-3.0"):New(myname.."DB", ns.defaults)
    ns.db = self.db.profile
    ns.hidden = self.db.char.hidden
    -- Initialize our database with HandyNotes
    HandyNotes:RegisterPluginDB(myname:gsub("HandyNotes_", ""), HLHandler, ns.options)

    -- watch for LOOT_CLOSED
    self:RegisterEvent("LOOT_CLOSED", "Refresh")
    self:RegisterEvent("ZONE_CHANGED_INDOORS", "Refresh")
end

function HL:Refresh()
    self:SendMessage("HandyNotes_NotifyUpdate", myname:gsub("HandyNotes_", ""))
end
